@@ -13,10 +13,10 @@ class SkinListDelegate : public QAbstractItemDelegate
 {
 public:
     explicit SkinListDelegate(QObject *parent = nullptr);
-    ~SkinListDelegate();
+    ~SkinListDelegate() override;
 
-    void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const Q_DECL_OVERRIDE;
-    QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const Q_DECL_OVERRIDE;
+    void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const override;
+    QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const override;
 
 private:
     void paintBackground(QPainter *painter, const QStyleOptionViewItem &option) const;
